"""Test that we can create custom MagicTodo classes."""

from __future__ import annotations

from typing import List

from pytest import mark

from magodo import MagicTodoMixin
from magodo.types import TodoSpell


params = mark.parametrize


def to_test_line(line: str) -> str:
    """Prepends 'test |' to `line`."""
    return "test | " + line


def from_test_line(line: str) -> str:
    """Removes 'test | ' from `line`."""
    return line.replace("test | ", "")


class LineTodo(MagicTodoMixin):
    """MagicTodo that adds 'test | ' to the beginning of each line."""

    from_line_spells = [from_test_line]
    to_line_spells = [to_test_line]
    todo_spells: List[TodoSpell] = []

    ident: str = "LINE TODO"


@params("line", ["1900-01-01 foo bar baz", "test | 1900-01-01 foo bar baz"])
def test_line_todo(line: str) -> None:
    """Test that to_line and from_line spells work."""
    todo = LineTodo.from_line(line).unwrap()
    assert todo.desc == "foo bar baz"
    assert todo.to_line() == "test | 1900-01-01 foo bar baz"



"""Utilities for working with dates in magodo."""

from __future__ import annotations

import datetime as dt
from typing import Final


DATE_FMT: Final = "%Y-%m-%d"


def to_date(yyyymmdd: str) -> dt.date:
    """Helper function for constructing a date object."""
    return dt.datetime.strptime(yyyymmdd, DATE_FMT).date()


def from_date(date: dt.date) -> str:
    """Helper function for converting a date object to a string."""
    return date.strftime(DATE_FMT)



"""A Python library for working with the todo.txt format."""

import logging as _logging

from . import dates, tags, types
from ._common import DEFAULT_PRIORITY, PUNCTUATION
from ._magic import MagicTodoMixin
from ._todo import Todo


__all__ = [
    "DEFAULT_PRIORITY",
    "MagicTodoMixin",
    "PUNCTUATION",
    "Todo",
    "dates",
    "tags",
    "types",
]

__author__ = "Bryan M Bugyi"
__email__ = "bryanbugyi34@gmail.com"
__version__ = "1.0.0"

_logging.getLogger(__name__).addHandler(_logging.NullHandler())
